package org.jdtaus.banking.messages;

import java.util.HashMap;
import java.util.Map;
import java.util.Locale;
import java.util.ResourceBundle;
import java.text.MessageFormat;

abstract class CurrencyConstraintMessageBundle{

private static final Map cache;

static
{
    cache = new HashMap();
    getCurrencyConstraintText(Locale.getDefault());
}

/** <pre> The {0} currency is in use but not valid at {1,date,long}.</pre>. */
public static String getCurrencyConstraintText(final Locale locale) {
    return getMessage("currencyConstraint", locale);
}

/** <pre> The {0} currency is in use but not valid at {1,date,long}.</pre>. */
public static MessageFormat getCurrencyConstraintMessage(Locale locale) {
    if(locale == null) { locale = Locale.getDefault(); }
return new MessageFormat(getMessage("currencyConstraint", locale), locale);
}

private static String getMessage(final String key, Locale locale) {
    if(locale == null) {locale = Locale.getDefault(); }
    Map msgCache = (Map) cache.get(locale);
    if(msgCache == null)
    {
        msgCache = new HashMap();
        cache.put(locale, msgCache);
    }

    String msg = (String) msgCache.get(key);
    if(msg == null)
    {
        msg = ResourceBundle.getBundle(
        "org.jdtaus.banking.messages.CurrencyConstraintMessage", locale).getString(key);
        msgCache.put(key, msg);
    };
    return msg;
}

}
